@@ -5,3 +5,5 @@ from .moji import Moji
 from .hujiang import Hujiang
 from .foxit import Foxit
 from .google import Google
+from .souka import Souka
+from .crown import Crown
