@@ -1,3 +1,5 @@
+import os
+
 from sihodictapi.mdict_query import IndexBuilder
 
 
@@ -5,9 +7,9 @@ class Crown:
     """
     超級クラウン中日辞典/クラウン日中辞典
     """
-
-    _builder_jc = IndexBuilder('超級クラウン日中辞典.mdx')
-    _builder_cj = IndexBuilder('超級クラウン中日辞典.mdx')
+    _current_dir = os.path.dirname(os.path.abspath(__file__))
+    _builder_jc = IndexBuilder(os.path.join(_current_dir, '超級クラウン日中辞典.mdx'))
+    _builder_cj = IndexBuilder(os.path.join(_current_dir, '超級クラウン中日辞典.mdx'))
 
     @classmethod
     def dict_search(cls, text: str) -> (list, list):
